@@ -30,24 +30,34 @@
 #include <stdio.h>
 #include <string.h>
 #include <errno.h>
+#ifdef RELEASE
+#undef DEBUGFUNCTIONCALL
+#endif
 /*******************************************************************************/
-GtkListStore* create_items_list(const char *filename, long start, long end,
-							    long *items_number){
+GtkListStore* create_items_list(const char *path, const char *filename,
+				long start, long end, long *items_number){
     FILE		*fh;
     GtkListStore	*list = NULL;
     GtkTreeIter		iter;
-    char		buffer[512];
+    gchar		buffer[512],
+			buff[512];
     Region_item		r_item;
     Country_item	c_item;    
     Station		station;
     long		max_bytes = 0,
 			readed_bytes = 0,
 			count = 0;
-    
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+/* prepare full file name with path */
+    buff[0] = 0;
+    snprintf(buff, sizeof(buff) - 1, "%s%s", path, filename);
+
     max_bytes = end - start;
-    fh = fopen(filename, "rt");
+    fh = fopen(buff, "rt");
     if(!fh){
-	fprintf(stderr, "\nCan't read file %s: %s", filename,
+	fprintf(stderr, "\nCan't read file %s: %s", buff,
 		strerror(errno));
 	items_number && (*items_number = count);
 	list = NULL;
@@ -62,7 +72,7 @@ GtkListStore* create_items_list(const char *filename, long start, long end,
 	    if(fseek(fh, start, SEEK_SET)){
 		fprintf(stderr,
 			"\nCan't seek to the position %ld on %s file: %s\n",
-			start, filename, strerror(errno));
+			start, buff, strerror(errno));
 		items_number && (*items_number = count);
 		return NULL;
 	    }
@@ -122,7 +132,9 @@ int parse_country_string(const char *string, Country_item *result){
 		*tmp,
 		buffer[32];
     int		res = 0;
-    
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     tmp = (char*)string;
     delimiter = strchr(tmp, ';');
     if(!delimiter)
@@ -165,7 +177,9 @@ int parse_region_string(const char *string, Region_item *result){
     char	*delimiter = NULL,
 		*tmp;
     int		res = 0;
-    
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif    
     tmp = (char*)string;
     delimiter = strchr(tmp, ';');
     setlocale(LC_NUMERIC, "POSIX");
@@ -245,7 +259,9 @@ int parse_station_string(const char *string, Station *result){
     char	*delimiter = NULL,
 		*tmp;
     int		res = 0;
-    
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif    
     tmp = (char*)string;
     delimiter = strchr(tmp, ';');
     setlocale(LC_NUMERIC, "POSIX");
